@@ -20,28 +20,38 @@
 """Basic large tests class"""
 
 from contextlib import suppress
+from nose.tools import nottest
 import os
 import pexpect
 import shutil
 import signal
+import stat
 import subprocess
 from time import sleep
 from umake.tools import get_icon_path, get_launcher_path, launcher_exists_and_is_pinned, remove_framework_envs_from_user
-from ..tools import LoggedTestCase, get_path_from_desktop_file, is_in_group
+from ..tools import LoggedTestCase, get_path_from_desktop_file, is_in_group, INSTALL_DIR, swap_file_and_restore, \
+    spawn_process
+from umake.settings import DEFAULT_BINARY_LINK_PATH
 
 
 class LargeFrameworkTests(LoggedTestCase):
     """Large framework base utilities"""
 
+    in_container = False
+
     def setUp(self):
         super().setUp()
-        self.in_container = False
         self.installed_path = ""
         self.framework_name_for_profile = ""
         self.conf_path = os.path.expanduser("~/.config/umake")
+        self.install_base_path = os.path.expanduser("~/{}".format(INSTALL_DIR))
+        self.binary_dir = DEFAULT_BINARY_LINK_PATH
         self.desktop_filename = ""
         self.child = None
         self.additional_dirs = []
+        self.original_env = os.environ.copy()
+        # we want to standardize on bash environment for running large tests
+        os.environ["SHELL"] = "/bin/bash"
 
     def tearDown(self):
         # don't remove on machine paths if running within a container
@@ -58,6 +68,10 @@ class LargeFrameworkTests(LoggedTestCase):
             for dir in self.additional_dirs:
                 with suppress(OSError):
                     shutil.rmtree(dir)
+        # restore original environment. Do not use the dict copy which erases the object and doesn't have the magical
+        # _Environ which setenv() for subprocess
+        os.environ.clear()
+        os.environ.update(self.original_env)
         super().tearDown()
 
     def _pid_for(self, process_grep):
@@ -105,6 +119,10 @@ class LargeFrameworkTests(LoggedTestCase):
         """Assert that the icon path exists"""
         self.assertTrue(self.path_exists(self._get_path_from_desktop_file('Icon', get_icon_path)))
 
+    def assert_exec_link_exists(self):
+        """Assert that the link to the binary exists"""
+        self.assertTrue(self.is_in_path(os.path.join(self.binary_dir, self.desktop_filename.split('.')[0])))
+
     def assert_for_warn(self, content, expect_warn=False):
         """assert if there is any warn"""
         if not expect_warn:
@@ -151,6 +169,16 @@ class LargeFrameworkTests(LoggedTestCase):
         self.child.sendline("")
         self.wait_and_no_warn(expect_warn)
 
+    def close_and_check_status(self, exit_status=0):
+        """exit child process and check its exit status"""
+        self.child.close()
+        self.assertEqual(exit_status, self.child.exitstatus)
+
+    def wait_and_close(self, expect_warn=False, exit_status=0):
+        """wait for exiting and check exit status"""
+        self.wait_and_no_warn(expect_warn)
+        self.close_and_check_status(exit_status)
+
     def command(self, commands_to_run):
         """passthrough, return args"""
         return commands_to_run
@@ -159,6 +187,10 @@ class LargeFrameworkTests(LoggedTestCase):
         """passthrough, return args"""
         return commands_input
 
+    def get_launcher_path(self, desktop_filename):
+        """passthrough getting the launcher path from umake tools"""
+        return get_launcher_path(desktop_filename)
+
     def launcher_exists_and_is_pinned(self, desktop_filename):
         """passthrough to in process method"""
         return launcher_exists_and_is_pinned(desktop_filename)
@@ -167,6 +199,13 @@ class LargeFrameworkTests(LoggedTestCase):
         """passthrough to os.path.exists"""
         return os.path.exists(path)
 
+    def remove_path(self, path):
+        """Remove targeted path"""
+        try:
+            os.remove(path)
+        except OSError:
+            shutil.rmtree(path)
+
     def is_in_path(self, filename):
         """check that we have a directory in path"""
         return_code = subprocess.call(["bash", "-l", "which", filename], stdin=subprocess.DEVNULL,
@@ -181,6 +220,21 @@ class LargeFrameworkTests(LoggedTestCase):
         """return if current user is in a group"""
         return is_in_group(group)
 
+    def get_file_perms(self, path):
+        """return unix file perms string for path"""
+        return stat.filemode(os.stat(path).st_mode)
+
     def create_file(self, path, content):
         """passthrough to create a file on the disk"""
         open(path, 'w').write(content)
+
+    @nottest
+    def bad_download_page_test(self, command, content_file_path):
+        """Helper for running a test to confirm failure on a significantly changed download page."""
+        with swap_file_and_restore(content_file_path):
+            with open(content_file_path, "w") as newfile:
+                newfile.write("foo")
+            self.child = spawn_process(command)
+            self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
+            self.child.sendline("")
+            self.wait_and_close(expect_warn=True, exit_status=1)
