@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 # Copyright (C) 2014 Canonical
 #
@@ -20,13 +19,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 """Tests for the Go category"""
-import platform
 import subprocess
 import os
-import pexpect
 import tempfile
 from tests.large import LargeFrameworkTests
-from tests.tools import UMAKE
+from tests.tools import UMAKE, spawn_process
 
 
 class GoTests(LargeFrameworkTests):
@@ -40,7 +37,7 @@ class GoTests(LargeFrameworkTests):
 
     def setUp(self):
         super().setUp()
-        self.installed_path = os.path.expanduser("~/tools/go/go-lang")
+        self.installed_path = os.path.join(self.install_base_path, "go", "go-lang")
         self.framework_name_for_profile = "Go Lang"
 
     @property
@@ -48,7 +45,7 @@ class GoTests(LargeFrameworkTests):
         return os.path.join(self.installed_path, "bin", "go")
 
     def test_default_go_install(self):
-        """Install eclipse from scratch test case"""
+        """Install Go from scratch test case"""
         if not self.in_container:
             self.example_prog_dir = tempfile.mkdtemp()
             self.additional_dirs.append(self.example_prog_dir)
@@ -58,19 +55,17 @@ class GoTests(LargeFrameworkTests):
         else:  # our mock expects getting that path
             compile_command = ["bash", "-l", "go run /tmp/hello.go"]
 
-        self.child = pexpect.spawnu(self.command('{} go'.format(UMAKE)))
+        self.child = spawn_process(self.command('{} go'.format(UMAKE)))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
         self.child.sendline("")
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_no_warn()
+        self.wait_and_close()
 
         self.assert_exec_exists()
         self.assertTrue(self.is_in_path(self.exec_path))
 
         # compile a small project
-        output = subprocess.check_output(self.command_as_list(compile_command)).decode()
+        output = subprocess.check_output(self.command_as_list(compile_command)).decode()\
+            .replace('\r', '').replace('\n', '')
 
-        if self.in_container:
-            self.assertEqual(output, "hello, world\r\n")
-        else:
-            self.assertEqual(output, "hello, world")
+        self.assertEqual(output, "hello, world")
