@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 # Copyright (C) 2015 Canonical
 #
@@ -23,9 +22,8 @@ import logging
 import platform
 import subprocess
 import os
-import pexpect
 from tests.large import LargeFrameworkTests
-from tests.tools import UMAKE
+from tests.tools import UMAKE, spawn_process
 
 logger = logging.getLogger(__name__)
 
@@ -39,7 +37,7 @@ class FirefoxDevTests(LargeFrameworkTests):
 
     def setUp(self):
         super().setUp()
-        self.installed_path = os.path.expanduser("~/tools/web/firefox-dev")
+        self.installed_path = os.path.join(self.install_base_path, "web", "firefox-dev")
         self.desktop_filename = "firefox-developer.desktop"
 
     @property
@@ -53,6 +51,7 @@ class FirefoxDevTests(LargeFrameworkTests):
         self.assertTrue(self.language_file_exists(installed_language))
         self.assert_exec_exists()
         self.assert_icon_exists()
+        self.assert_exec_link_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -63,52 +62,54 @@ class FirefoxDevTests(LargeFrameworkTests):
         proc.wait(self.TIMEOUT_STOP)
 
         # ensure that it's detected as installed:
-        self.child = pexpect.spawnu(self.command('{} web firefox-dev'.format(UMAKE)))
+        self.child = spawn_process(self.command('{} web firefox-dev'.format(UMAKE)))
         self.expect_and_no_warn("Firefox Dev is already installed.*\[.*\] ")
         self.child.sendline()
-        self.wait_and_no_warn()
+        self.wait_and_close()
 
     def test_default_install(self):
         """Install firefox dev from scratch test case"""
         install_language = "en-US"
-        self.child = pexpect.spawnu(self.command('{} web firefox-dev'.format(UMAKE)))
+        self.child = spawn_process(self.command('{} web firefox-dev'.format(UMAKE)))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
         self.child.sendline("")
         self.expect_and_no_warn("Choose language:")
         self.child.sendline("")
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_no_warn()
+        self.wait_and_close()
         self.verify_install(install_language)
 
     def test_arg_language_select_install(self):
         """Install firefox dev with language selected by --lang"""
         install_language = "bg"
-        self.child = pexpect.spawnu(self.command('{} web firefox-dev --lang={}'.format(UMAKE, install_language)))
+        self.child = spawn_process(self.command('{} web firefox-dev --lang={}'.format(UMAKE, install_language)))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
         self.child.sendline("")
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_no_warn()
+        self.wait_and_close()
         self.verify_install(install_language)
 
     def test_interactive_language_select_install(self):
         """Install firefox dev with language selected interactively"""
         install_language = "bg"
-        self.child = pexpect.spawnu(self.command('{} web firefox-dev'.format(UMAKE)))
+        self.child = spawn_process(self.command('{} web firefox-dev'.format(UMAKE)))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
         self.child.sendline("")
         self.expect_and_no_warn("Choose language:")
         self.child.sendline(install_language)
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_no_warn()
+        self.wait_and_close()
         self.verify_install(install_language)
 
     def test_unavailable_language_select_install(self):
+        """Installing Firefox-dev in unavailable language should be rejected"""
         install_language = "ABCdwXYZ"
-        self.child = pexpect.spawnu(self.command('{} web firefox-dev --lang={}'.format(UMAKE, install_language)))
+        self.child = spawn_process(self.command('{} web firefox-dev --lang={}'.format(UMAKE, install_language)))
         self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
-        self.accept_default_and_wait(expect_warn=True)
-        self.child.close()
-        self.assertEqual(self.child.exitstatus, 1)
+        self.child.sendline("")
+        self.wait_and_close(expect_warn=True, exit_status=1)
+
+        self.assertFalse(self.launcher_exists_and_is_pinned(self.desktop_filename))
 
     def language_file_exists(self, language):
         return self.path_exists(os.path.join(self.installed_path, "dictionaries", "{}.aff".format(language)))
@@ -123,19 +124,19 @@ class VisualStudioCodeTest(LargeFrameworkTests):
 
     def setUp(self):
         super().setUp()
-        self.installed_path = os.path.expanduser("~/tools/web/visual-studio-code")
+        self.installed_path = os.path.join(self.install_base_path, "web", "visual-studio-code")
         self.desktop_filename = "visual-studio-code.desktop"
 
     def test_default_install(self):
         """Install visual studio from scratch test case"""
 
-        self.child = pexpect.spawnu(self.command('{} web visual-studio-code'.format(UMAKE)))
-        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
+        self.child = spawn_process(self.command('{} web visual-studio-code'.format(UMAKE)))
+        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path), expect_warn=True)
         self.child.sendline("")
         self.expect_and_no_warn("\[I Accept.*\]")  # ensure we have a license question
         self.child.sendline("a")
         self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
-        self.wait_and_no_warn()
+        self.wait_and_close()
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
@@ -151,7 +152,7 @@ class VisualStudioCodeTest(LargeFrameworkTests):
         proc.wait(self.TIMEOUT_STOP)
 
         # ensure that it's detected as installed:
-        self.child = pexpect.spawnu(self.command('{} web visual-studio-code'.format(UMAKE)))
-        self.expect_and_no_warn("Visual Studio Code is already installed.*\[.*\] ")
+        self.child = spawn_process(self.command('{} web visual-studio-code'.format(UMAKE)))
+        self.expect_and_no_warn("Visual Studio Code is already installed.*\[.*\] ", expect_warn=True)
         self.child.sendline()
-        self.wait_and_no_warn()
+        self.wait_and_close()
