@@ -20,8 +20,10 @@
 """Tests for basic CLI commands"""
 
 import os
+import pwd
 import subprocess
-from ..tools import get_root_dir, get_tools_helper_dir, LoggedTestCase, get_docker_path, get_data_dir
+from ..tools import get_root_dir, get_tools_helper_dir, LoggedTestCase, get_docker_path, get_data_dir, INSTALL_DIR, \
+    BRANCH_TESTS, SYSTEM_UMAKE_DIR, BINARY_DIR
 from time import sleep
 
 
@@ -29,43 +31,70 @@ class ContainerTests(LoggedTestCase):
     """Container-based tests utilities"""
 
     DOCKER_USER = "user"
-    DOCKER_PASSWORD = "user"
     DOCKER_TESTIMAGE = "didrocks/docker-umake-manual"
-    UMAKE_IN_CONTAINER = "/umake"
+    UMAKE_TOOLS_IN_CONTAINER = "/umake"
     APT_FAKE_REPO_PATH = "/apt-fake-repo"
 
+    in_container = True
+
     def setUp(self):
         super().setUp()  # this will call other parents of ContainerTests ancestors, like LargeFrameworkTests
-        self.in_container = True
         self.umake_path = get_root_dir()
+        self.install_base_path = os.path.expanduser("/home/{}/{}".format(self.DOCKER_USER, INSTALL_DIR))
+        self.binary_dir = os.path.join(self.install_base_path, BINARY_DIR)
         self.image_name = self.DOCKER_TESTIMAGE
+        if not hasattr(self, "hosts"):
+            self.hosts = {}
+        if not hasattr(self, "additional_local_frameworks"):
+            self.additional_local_frameworks = []
         command = [get_docker_path(), "run"]
-        runner_cmd = "mkdir -p {}; ln -s {}/ {};".format(os.path.dirname(get_root_dir()), self.UMAKE_IN_CONTAINER,
+
+        # bind master used for testing tools code inside the container
+        runner_cmd = "mkdir -p {}; ln -s {}/ {};".format(os.path.dirname(get_root_dir()), self.UMAKE_TOOLS_IN_CONTAINER,
                                                          get_root_dir())
 
+        local_framework_dir = "/home/{}/.umake/frameworks/".format(self.DOCKER_USER)
+        runner_cmd += "mkdir -p {};".format(local_framework_dir)
+        for additional_framework in self.additional_local_frameworks:
+            runner_cmd += "cp {} {};".format(
+                os.path.join(self.UMAKE_TOOLS_IN_CONTAINER, additional_framework), local_framework_dir)
+
+        if not BRANCH_TESTS:
+            # create a system binary which will use system umake version (without having the package installed)
+            bin_umake = "/usr/bin/umake"
+            runner_cmd += "echo '#!/usr/bin/env python3\nfrom umake import main\nif __name__ == \"__main__\":" \
+                          "\n  main()'>{bin_umake}; chmod +x {bin_umake};".format(bin_umake=bin_umake)
+
         # start the local server at container startup
-        if hasattr(self, "hostname"):
+        for port, hostnames in self.hosts.items():
             ftp_redir = hasattr(self, 'ftp')
-            command.extend(["-h", self.hostname])
+            for hostname in hostnames:
+                if "-h" not in command:
+                    command.extend(["-h", hostname])
+                runner_cmd += ' echo "127.0.0.1 {}" >> /etc/hosts;'.format(hostname)
             runner_cmd += "{} {} 'sudo -E env PATH={} VIRTUAL_ENV={} {} {} {} {}';".format(
                 os.path.join(get_tools_helper_dir(), "run_in_umake_dir_async"),
-                self.UMAKE_IN_CONTAINER,
+                self.UMAKE_TOOLS_IN_CONTAINER,
                 os.getenv("PATH"), os.getenv("VIRTUAL_ENV"),
                 os.path.join(get_tools_helper_dir(), "run_local_server"),
-                self.port,
-                self.hostname,
-                str(ftp_redir))
+                str(port),
+                str(ftp_redir),
+                " ".join(hostnames) if port == 443 else "")
 
             if ftp_redir:
                 runner_cmd += "/usr/bin/twistd ftp -p 21 -r {};".format(os.path.join(get_data_dir(), 'server-content',
-                                                                        self.hostname))
+                                                                                     hostnames[0]))
 
         if hasattr(self, "apt_repo_override_path"):
-            runner_cmd += "sudo sh -c 'echo deb file:{} / > /etc/apt/sources.list';sudo apt-get update;".format(
+            runner_cmd += "sh -c 'echo deb file:{} / > /etc/apt/sources.list'; apt-get update;".format(
                 self.apt_repo_override_path)
         runner_cmd += "/usr/sbin/sshd -D"
 
-        command.extend(["-d", "-v", "{}:{}".format(self.umake_path, self.UMAKE_IN_CONTAINER),
+        # we bindmount system umake directory
+        if not BRANCH_TESTS:
+            command.extend(["-v", "{system_umake}:{system_umake}".format(system_umake=SYSTEM_UMAKE_DIR)])
+
+        command.extend(["-d", "-v", "{}:{}".format(self.umake_path, self.UMAKE_TOOLS_IN_CONTAINER),
                         "--dns=8.8.8.8", "--dns=8.8.4.4",  # suppress local DNS warning
                         self.image_name,
                         'sh', '-c', runner_cmd])
@@ -93,11 +122,11 @@ class ContainerTests(LoggedTestCase):
 
         if isinstance(commands_to_run, list):
             commands_to_run = " ".join(commands_to_run)
-        return ["sshpass", "-p", self.DOCKER_PASSWORD, "ssh", "-o", "UserKnownHostsFile=/dev/null", "-o",
-                "StrictHostKeyChecking=no", "-t", "-q",
+        return ["ssh", "-i", os.path.join(get_root_dir(), "docker", "umake_docker"),
+                "-o", "UserKnownHostsFile=/dev/null", "-o", "StrictHostKeyChecking=no", "-t", "-q",
                 "{}@{}".format(self.DOCKER_USER, self.container_ip),
                 "{} {} '{}'".format(os.path.join(get_tools_helper_dir(), "run_in_umake_dir"),
-                                    self.UMAKE_IN_CONTAINER, commands_to_run)]
+                                    self.UMAKE_TOOLS_IN_CONTAINER, commands_to_run)]
 
     def check_and_kill_process(self, process_grep, wait_before=0, send_sigkill=False):
         """Check a process matching process_grep exists and kill it"""
@@ -139,6 +168,12 @@ class ContainerTests(LoggedTestCase):
             return (False, stdout, stderr)
         raise BaseException("Unknown return code from {}".format(command))
 
+    def get_launcher_path(self, desktop_filename):
+        """Return launcher path inside container"""
+        command = self.command_as_list([os.path.join(get_tools_helper_dir(), "get_launcher_path"),
+                                        desktop_filename])
+        return self._exec_command(command)[1]
+
     def launcher_exists_and_is_pinned(self, desktop_filename):
         """Check if launcher exists and is pinned inside the container"""
         command = self.command_as_list([os.path.join(get_tools_helper_dir(), "check_launcher_exists_and_is_pinned"),
@@ -152,6 +187,12 @@ class ContainerTests(LoggedTestCase):
         command = self.command_as_list([os.path.join(get_tools_helper_dir(), "path_exists"), path])
         return self._exec_command(command)[0]
 
+    def remove_path(self, path):
+        """Remove targeted path"""
+        path = path.replace(os.environ['HOME'], "/home/{}".format(self.DOCKER_USER))
+        command = self.command_as_list([os.path.join(get_tools_helper_dir(), "remove_path"), path])
+        self._exec_command(command)
+
     def is_in_path(self, filename):
         """Check inside the container if filename is in PATH thanks to which"""
         return self._exec_command(self.command_as_list(["bash", "-l", "which", filename]))[0]
@@ -161,9 +202,23 @@ class ContainerTests(LoggedTestCase):
         command = self.command_as_list([os.path.join(get_tools_helper_dir(), "check_user_in_group"), group])
         return self._exec_command(command)[0]
 
+    def get_file_perms(self, path):
+        """return unix file perms string for path from the container"""
+        command = self.command_as_list([os.path.join(get_tools_helper_dir(), "get_file_perms"), path])
+        success, stdout, stderr = self._exec_command(command)
+        if success:
+            return stdout
+        else:
+            raise BaseException("Unknown failure from {}".format(command))
+
     def create_file(self, path, content):
         """Create file inside the container.replace in path current user with the docker user"""
-        path = path.replace(os.getlogin(), self.DOCKER_USER)
+        try:
+            src_user = os.getlogin()
+        except FileNotFoundError:
+            # fallback for container issues when trying to get login
+            src_user = pwd.getpwuid(os.getuid())[0]
+        path = path.replace(src_user, self.DOCKER_USER)
         dir_path = os.path.dirname(path)
         command = self.command_as_list(["mkdir", "-p", dir_path, path])
         if not self._exec_command(command)[0]:
