@@ -31,13 +31,18 @@ import os
 import re
 import shutil
 import xdg.BaseDirectory
+import pexpect
 from unittest import TestCase
 from unittest.mock import Mock
 
 logger = logging.getLogger(__name__)
 
+BRANCH_TESTS = False
 DOCKER = None
 UMAKE = "umake"
+INSTALL_DIR = ".local/share/umake"
+SYSTEM_UMAKE_DIR = "/usr/lib/python3/dist-packages/umake"
+BINARY_DIR = "bin"
 
 
 class LoggedTestCase(TestCase):
@@ -136,7 +141,9 @@ def swap_file_and_restore(filepath):
 
 def set_local_umake():
     global UMAKE
+    global BRANCH_TESTS
     UMAKE = "./bin/umake"
+    BRANCH_TESTS = True
 
 
 def get_docker_path():
@@ -157,16 +164,25 @@ def local_which(filename):
     return None
 
 
-def get_path_from_desktop_file(desktop_filename, key):
-    """get the path referred as key in the desktop filename exists"""
+def get_desktop_file_path(desktop_filename):
+    """get the desktop file path"""
     if not desktop_filename:
         return ""
 
     from umake.tools import get_launcher_path
     importlib.reload(xdg.BaseDirectory)
 
+    return get_launcher_path(desktop_filename)
+
+
+def get_path_from_desktop_file(desktop_filename, key):
+    """get the path referred as key in the desktop filename exists"""
+    desktop_file_path = get_desktop_file_path(desktop_filename)
+    if not get_desktop_file_path(desktop_file_path):
+        return ""
+
     path = ""
-    with open(get_launcher_path(desktop_filename)) as f:
+    with open(desktop_file_path) as f:
         for line in f:
             p = re.search(r'{}=(.*)'.format(key), line)
             with suppress(AttributeError):
@@ -196,3 +212,8 @@ def is_in_group(group):
         if group_name == group:
             return True
     return False
+
+
+def spawn_process(command):
+    """return a handle to a new controllable child process"""
+    return pexpect.spawnu(command, dimensions=(24, 250))
