@@ -42,26 +42,49 @@ logger = logging.getLogger(__name__)
 class LocalHttp:
     """Local threaded http server. will be serving path content"""
 
-    def __init__(self, path, use_ssl=False, port=9876, ftp_redir=False):
+    def __init__(self, path, multi_hosts=False, use_ssl=[], port=9876, ftp_redir=False):
         """path is the local path to server
-        set use_ssl to a specific filename turn on the use of the local certificate
+        multi_hosts will transfer http://hostname/foo to path/hostname/foo. This is used when we potentially serve
+        multiple paths.
+        set use_ssl to a specific array of hostnames. We'll use the corresponding certificates.
         """
         self.port = port
         self.path = path
         self.use_ssl = use_ssl
         handler = RequestHandler
         handler.root_path = path
+        handler.multi_hosts = multi_hosts
         handler.ftp_redir = ftp_redir
         # can be TCPServer, but we don't have a self.httpd.server_name then
         self.httpd = HTTPServer(("", self.port), RequestHandler)
         handler.hostname = self.httpd.server_name
-        if self.use_ssl:
-            self.httpd.socket = ssl.wrap_socket(self.httpd.socket,
-                                                certfile=os.path.join(get_data_dir(), self.use_ssl),
-                                                server_side=True)
+
+        # create ssl certificate handling for SNI case (switching between different host name)
+        self.ssl_contexts = {}
+        context_associated = False
+        for hostname in self.use_ssl:
+            pem_file = os.path.join(get_data_dir(), "{}.pem".format(hostname))
+            if os.path.isfile(pem_file):
+                context = ssl.SSLContext(ssl.PROTOCOL_TLSv1)
+                context.load_cert_chain(pem_file)
+                self.ssl_contexts[hostname] = context
+                if not context_associated:
+                    context_associated = True
+                    self.httpd.socket = context.wrap_socket(self.httpd.socket, server_side=True)
+                    context.set_servername_callback(self._match_sni_context)
+
         executor = futures.ThreadPoolExecutor(max_workers=1)
         self.future = executor.submit(self._serve)
 
+    def _match_sni_context(self, ssl_sock, server_name, initial_context):
+        """return matching certificates to the current request"""
+        logger.info("Request on {}".format(server_name))
+        try:
+            ssl_sock.context = self.ssl_contexts[server_name]
+        except KeyError:
+            logger.warning("Didn't find corresponding context on this server for {}, keeping default"
+                           .format(server_name))
+
     def _serve(self):
         logger.info("Serving locally from {} on {}".format(self.path, self.get_address()))
         self.httpd.serve_forever()
@@ -89,7 +112,8 @@ class RequestHandler(SimpleHTTPRequestHandler):
 
     def end_headers(self):
         """don't send Content-Length header for a particular file"""
-        if self.path.endswith("-with-no-content-length"):
+        # we can send 404, so ensure that we have a valid path attribute
+        if hasattr(self, "path") and self.path.endswith("-with-no-content-length"):
             for current_header in self._headers_buffer:
                 if current_header.decode("UTF-8").startswith("Content-Length"):
                     self._headers_buffer.remove(current_header)
@@ -106,8 +130,12 @@ class RequestHandler(SimpleHTTPRequestHandler):
         # Before we actually abandon the query params, see if they match an
         # actual file.
         # Need to strip the leading '/' so the join will actually work.
+        current_root_path = RequestHandler.root_path
+        if RequestHandler.multi_hosts:
+            current_root_path = os.path.join(RequestHandler.root_path, self.headers["Host"].split(":")[0])
+
         file_path = posixpath.normpath(urllib.parse.unquote(path))[1:]
-        file_path = os.path.join(RequestHandler.root_path, file_path)
+        file_path = os.path.join(current_root_path, file_path)
         if os.path.exists(file_path):
             return file_path
 
@@ -121,8 +149,8 @@ class RequestHandler(SimpleHTTPRequestHandler):
         words = path.split('/')
         words = filter(None, words)
 
-        # root path isn't cwd but the one we specified
-        path = RequestHandler.root_path
+        # root path isn't cwd but the one we specified and translated
+        path = current_root_path
 
         for word in words:
             drive, word = os.path.splitdrive(word)
