@@ -29,7 +29,7 @@ import re
 import umake.frameworks.baseinstaller
 from umake.interactions import DisplayMessage
 from umake.ui import UI
-from umake.tools import create_launcher, get_application_desktop_file, ChecksumType
+from umake.tools import add_env_to_user, create_launcher, get_application_desktop_file, ChecksumType
 
 logger = logging.getLogger(__name__)
 
@@ -41,9 +41,9 @@ class AndroidCategory(umake.frameworks.BaseCategory):
     def __init__(self):
         super().__init__(name="Android", description=_("Android Development Environment"), logo_path=None)
 
-    def parse_license(self, line, license_txt, in_license):
+    def parse_license(self, tag, line, license_txt, in_license):
         """Parse Android download page for license"""
-        if line.startswith('<p class="sdk-terms-intro">'):
+        if line.startswith(tag):
             in_license = True
         if in_license:
             if line.startswith('</div>'):
@@ -84,11 +84,12 @@ class AndroidStudio(umake.frameworks.baseinstaller.BaseInstaller):
                          download_page="https://developer.android.com/sdk/index.html",
                          checksum_type=ChecksumType.sha1,
                          dir_to_decompress_in_tarball="android-studio",
-                         desktop_filename="android-studio.desktop")
+                         desktop_filename="android-studio.desktop",
+                         required_files_path=[os.path.join("bin", "studio.sh")])
 
     def parse_license(self, line, license_txt, in_license):
         """Parse Android Studio download page for license"""
-        return self.category.parse_license(line, license_txt, in_license)
+        return self.category.parse_license('<p class="sdk-terms-intro">', line, license_txt, in_license)
 
     def parse_download_link(self, line, in_download):
         """Parse Android Studio download link, expect to find a md5sum and a url"""
@@ -103,28 +104,59 @@ class AndroidStudio(umake.frameworks.baseinstaller.BaseInstaller):
                         categories="Development;IDE;",
                         extra="StartupWMClass=jetbrains-android-studio"))
 
-    @property
-    def is_installed(self):
-        # check path and requirements
-        if not super().is_installed:
-            return False
-        if not os.path.isfile(os.path.join(self.install_path, "bin", "studio.sh")):
-            logger.debug("{} binary isn't installed".format(self.name))
-            return False
-        return True
+
+class AndroidSDK(umake.frameworks.baseinstaller.BaseInstaller):
+
+    def __init__(self, category):
+        super().__init__(name="Android SDK", description=_("Android SDK"),
+                         category=category, only_on_archs=_supported_archs, expect_license=True,
+                         packages_requirements=["openjdk-7-jdk", "libncurses5:i386", "libstdc++6:i386", "zlib1g:i386",
+                                                "jayatana"],
+                         download_page="https://developer.android.com/sdk/index.html",
+                         checksum_type=ChecksumType.sha1,
+                         dir_to_decompress_in_tarball="android-sdk-linux",
+                         required_files_path=[os.path.join("tools", "android")])
+
+    def parse_license(self, line, license_txt, in_license):
+        """Parse Android SDK download page for license"""
+        return self.category.parse_license('<p class="sdk-terms-intro">', line, license_txt, in_license)
+
+    def parse_download_link(self, line, in_download):
+        """Parse Android SDK download link, expect to find a SHA-1 and a url"""
+        return self.category.parse_download_link('id="linux-tools"', line, in_download)
+
+    def post_install(self):
+        """Add necessary environment variables"""
+        add_env_to_user(self.name, {"ANDROID_HOME": {"value": self.install_path, "keep": False}})
+        # add "platform-tools" to PATH to ensure "adb" can be run once the platform tools are installed via
+        # the SDK manager
+        add_env_to_user(self.name, {"PATH": {"value": [os.path.join("$ANDROID_HOME", "tools"),
+                                                       os.path.join("$ANDROID_HOME", "platform-tools")]}})
+        UI.delayed_display(DisplayMessage(_("You need to restart your current shell session for your {} installation "
+                                            "to work properly").format(self.name)))
+
+        # print wiki page message
+        UI.delayed_display(DisplayMessage("SDK installed in {}. More information on how to use it on {}".format(
+                                          self.install_path,
+                                          "https://developer.android.com/sdk/installing/adding-packages.html")))
 
 
 class AndroidNDK(umake.frameworks.baseinstaller.BaseInstaller):
 
     def __init__(self, category):
         super().__init__(name="Android NDK", description=_("Android NDK"),
-                         category=category, only_on_archs=_supported_archs,
+                         category=category, only_on_archs=_supported_archs, expect_license=True,
                          download_page="https://developer.android.com/ndk/downloads/index.html",
                          checksum_type=ChecksumType.md5,
-                         dir_to_decompress_in_tarball="android-ndk-*")
+                         dir_to_decompress_in_tarball="android-ndk-*",
+                         required_files_path=[os.path.join("ndk-build")])
+
+    def parse_license(self, line, license_txt, in_license):
+        """Parse Android NDK download page for license"""
+        return self.category.parse_license('<div class="sdk-terms"', line, license_txt, in_license)
 
     def parse_download_link(self, line, in_download):
-        """Parse Android Studio download link, expect to find a md5sum and a url"""
+        """Parse Android NDK download link, expect to find a md5sum and a url"""
         arch = platform.machine()
         tag_machine = '64'
         if arch == 'i686':
@@ -132,21 +164,14 @@ class AndroidNDK(umake.frameworks.baseinstaller.BaseInstaller):
         return self.category.parse_download_link('<td>Linux {}'.format(tag_machine), line, in_download)
 
     def post_install(self):
-        """Print wiki page message"""
+        """Add necessary environment variables"""
+        add_env_to_user(self.name, {"NDK_ROOT": {"value": self.install_path, "keep": False}})
+
+        # print wiki page message
         UI.display(DisplayMessage("NDK installed in {}. More information on how to use it on {}".format(
                                   self.install_path,
                                   "https://developer.android.com/tools/sdk/ndk/index.html#GetStarted")))
 
-    @property
-    def is_installed(self):
-        # check path and requirements
-        if not super().is_installed:
-            return False
-        if not os.path.exists(os.path.join(self.install_path, "ndk-build")):
-            logger.debug("{} binary isn't installed".format(self.name))
-            return False
-        return True
-
 
 class EclipseADTForRemoval(umake.frameworks.baseinstaller.BaseInstaller):
 
