@@ -33,13 +33,15 @@ from umake.network.download_center import DownloadCenter, DownloadItem
 from umake.network.requirements_handler import RequirementsHandler
 from umake.ui import UI
 from umake.tools import MainLoop, strip_tags, launcher_exists, get_icon_path, get_launcher_path, \
-    Checksum, remove_framework_envs_from_user
+    Checksum, remove_framework_envs_from_user, add_exec_link
 
 logger = logging.getLogger(__name__)
 
 
 class BaseInstaller(umake.frameworks.BaseFramework):
 
+    DIRECT_COPY_EXT = ['.svg', '.png', '.ico', '.jpg', '.jpeg']
+
     def __new__(cls, *args, **kwargs):
         "This class is not meant to be instantiated, so __new__ returns None."
         if cls == BaseInstaller:
@@ -52,11 +54,15 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         having a set of downloads to proceed, some eventual supported_archs."""
         self.download_page = kwargs["download_page"]
         self.checksum_type = kwargs.get("checksum_type", None)
-        self.dir_to_decompress_in_tarball = kwargs.get("dir_to_decompress_in_tarball", None)
+        self.dir_to_decompress_in_tarball = kwargs.get("dir_to_decompress_in_tarball", "")
+        self.required_files_path = kwargs.get("required_files_path", [])
         self.desktop_filename = kwargs.get("desktop_filename", None)
         self.icon_filename = kwargs.get("icon_filename", None)
-        for extra_arg in ["download_page", "checksum_type",  "dir_to_decompress_in_tarball",
-                          "desktop_filename", "icon_filename"]:
+        self.match_last_link = kwargs.get("match_last_link", False)
+        self.exec_rel_path = kwargs.get("exec_rel_path", None)
+        for extra_arg in ["download_page", "checksum_type", "dir_to_decompress_in_tarball",
+                          "desktop_filename", "icon_filename", "required_files_path",
+                          "match_last_link", "exec_rel_path"]:
             with suppress(KeyError):
                 kwargs.pop(extra_arg)
         super().__init__(*args, **kwargs)
@@ -66,13 +72,24 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         self._arg_install_path = None
         self.download_requests = []
 
+    @property
+    def exec_link_name(self):
+        if self.desktop_filename:
+            return self.desktop_filename.split('.')[0]
+        return None
+
     @property
     def is_installed(self):
         # check path and requirements
         if not super().is_installed:
             return False
+        for required_file_path in self.required_files_path:
+            if not os.path.exists(os.path.join(self.install_path, required_file_path)):
+                logger.debug("{} binary isn't installed".format(self.name))
+                return False
         if self.desktop_filename:
             return launcher_exists(self.desktop_filename)
+        logger.debug("{} is installed".format(self.name))
         return True
 
     def setup(self, install_path=None, auto_accept_license=False):
@@ -105,6 +122,7 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         if self.desktop_filename:
             with suppress(FileNotFoundError):
                 os.remove(get_launcher_path(self.desktop_filename))
+                os.remove(os.path.join(self.default_binary_link_path, self.exec_link_name))
         if self.icon_filename:
             with suppress(FileNotFoundError):
                 os.remove(get_icon_path(self.icon_filename))
@@ -138,6 +156,10 @@ class BaseInstaller(umake.frameworks.BaseFramework):
                                      "there?".format(path_dir), self.set_installdir_to_clean, UI.return_main_screen))
                     return
         self.install_path = path_dir
+        if self.desktop_filename:
+            self.exec_path = os.path.join(self.install_path, self.required_files_path[0])
+        # if self.exec_rel_path:
+        #     self.exec_path = os.path.join(self.install_path, self.exec_rel_path)
         self.download_provider_page()
 
     def set_installdir_to_clean(self):
@@ -171,7 +193,7 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         error_msg = result[self.download_page].error
         if error_msg:
             logger.error("An error occurred while downloading {}: {}".format(self.download_page, error_msg))
-            UI.return_main_screen()
+            UI.return_main_screen(status_code=1)
 
         url, checksum = (None, None)
         with StringIO() as license_txt:
@@ -183,7 +205,10 @@ class BaseInstaller(umake.frameworks.BaseFramework):
                 if self.expect_license and not self.auto_accept_license:
                     in_license = self.parse_license(line_content, license_txt, in_license)
 
-                (download, in_download) = self.parse_download_link(line_content, in_download)
+                # always take the first valid (url, checksum) if not match_last_link is set to True:
+                download = None
+                if url is None or (self.checksum_type and not checksum) or self.match_last_link:
+                    (download, in_download) = self.parse_download_link(line_content, in_download)
                 if download is not None:
                     (newurl, new_checksum) = download
                     url = newurl if newurl is not None else url
@@ -191,14 +216,16 @@ class BaseInstaller(umake.frameworks.BaseFramework):
                     if url is not None:
                         if self.checksum_type and checksum:
                             logger.debug("Found download link for {}, checksum: {}".format(url, checksum))
-                            break
                         elif not self.checksum_type:
                             logger.debug("Found download link for {}".format(url))
-                            break
 
-            if url is None or (self.checksum_type and checksum is None):
-                logger.error("Download page changed its syntax or is not parsable")
-                UI.return_main_screen()
+            if url is None:
+                logger.error("Download page changed its syntax or is not parsable (url missing)")
+                UI.return_main_screen(status_code=1)
+            if (self.checksum_type and checksum is None):
+                logger.error("Download page changed its syntax or is not parsable (checksum missing)")
+                logger.error("URL is: {}".format(url))
+                UI.return_main_screen(status_code=1)
             self.download_requests.append(DownloadItem(url, Checksum(self.checksum_type, checksum)))
 
             if license_txt.getvalue() != "":
@@ -208,7 +235,7 @@ class BaseInstaller(umake.frameworks.BaseFramework):
                                             UI.return_main_screen))
             elif self.expect_license and not self.auto_accept_license:
                 logger.error("We were expecting to find a license on the download page, we didn't.")
-                UI.return_main_screen()
+                UI.return_main_screen(status_code=1)
             else:
                 self.start_download_and_install()
 
@@ -285,6 +312,9 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         """Chain up to main get_progress, returning current value between 0 and 100
 
         First call initialize the balance between requirements and download progress"""
+        # don't push any progress until we have the total download size
+        if len(downloads) != len(self.download_requests):
+            return
         total_size = 0
         total_current_size = 0
         for download in downloads:
@@ -294,12 +324,19 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         self.get_progress(total_current_size / total_size * 100, None)
 
     def requirement_done(self, result):
-        self.get_progress(None, 100)
+        # set requirement download as finished if no error
+        if not result.error:
+            self.get_progress(None, 100)
         self.result_requirement = result
         self.download_and_requirements_done()
 
     def download_done(self, result):
-        self.get_progress(100, None)
+        # set download as finished if no error
+        for url in result:
+            if result[url].error:
+                break
+        else:
+            self.get_progress(100, None)
         self.result_download = result
         self.download_and_requirements_done()
 
@@ -313,29 +350,46 @@ class BaseInstaller(umake.frameworks.BaseFramework):
         self.pbar.finish()
         # display eventual errors
         error_detected = False
-        fd = None
         if self.result_requirement.error:
-            logger.error(self.result_requirement.error)
+            logger.error("Package requirements can't be met: {}".format(self.result_requirement.error))
             error_detected = True
+
+        # check for any errors and collect fds
+        fds = []
         for url in self.result_download:
             if self.result_download[url].error:
                 logger.error(self.result_download[url].error)
                 error_detected = True
-            fd = self.result_download[url].fd
+            fds.append(self.result_download[url].fd)
         if error_detected:
-            UI.return_main_screen()
+            UI.return_main_screen(status_code=1)
 
-        self.decompress_and_install(fd)
+        # now decompress
+        self.decompress_and_install(fds)
 
-    def decompress_and_install(self, fd):
+    def decompress_and_install(self, fds):
         UI.display(DisplayMessage("Installing {}".format(self.name)))
         # empty destination directory if reinstall
         for dir_to_remove in self._paths_to_clean:
             with suppress(FileNotFoundError):
                 shutil.rmtree(dir_to_remove)
+            # marked them as cleaned
+            self._paths_to_clean = []
 
-        Decompressor({fd: Decompressor.DecompressOrder(dir=self.dir_to_decompress_in_tarball, dest=self.install_path)},
-                     self.decompress_and_install_done)
+        os.makedirs(self.install_path, exist_ok=True)
+        decompress_fds = {}
+        for fd in fds:
+            direct_copy = False
+            for ext in self.DIRECT_COPY_EXT:
+                if fd.name.endswith(ext):
+                    direct_copy = True
+                    break
+            if direct_copy:
+                shutil.copy2(fd.name, os.path.join(self.install_path, os.path.basename(fd.name)))
+            else:
+                decompress_fds[fd] = Decompressor.DecompressOrder(dir=self.dir_to_decompress_in_tarball,
+                                                                  dest=self.install_path)
+        Decompressor(decompress_fds, self.decompress_and_install_done)
         UI.display(UnknownProgress(self.iterate_until_install_done))
 
     def post_install(self):
@@ -352,10 +406,11 @@ class BaseInstaller(umake.frameworks.BaseFramework):
                 error_detected = True
             fd.close()
         if error_detected:
-            UI.return_main_screen()
+            UI.return_main_screen(status_code=1)
 
         self.post_install()
-
+        if self.exec_link_name:
+            add_exec_link(self.exec_path, self.exec_link_name)
         # Mark as installation done in configuration
         self.mark_in_config()
 
