@@ -46,12 +46,13 @@ class GoLang(umake.frameworks.baseinstaller.BaseInstaller):
         super().__init__(name="Go Lang", description=_("Google compiler (default)"), is_category_default=True,
                          category=category, only_on_archs=['i386', 'amd64'],
                          download_page="https://golang.org/dl/",
-                         checksum_type=ChecksumType.sha1,
-                         dir_to_decompress_in_tarball="go")
+                         checksum_type=ChecksumType.sha256,
+                         dir_to_decompress_in_tarball="go",
+                         required_files_path=[os.path.join("bin", "go")])
 
     def parse_download_link(self, line, in_download):
-        """Parse Go download link, expect to find a sha1 and a url"""
-        url, sha1 = (None, None)
+        """Parse Go download link, expect to find a sha and a url"""
+        url, sha = (None, None)
         if "linux-{}".format(get_current_arch().replace("i386", "386")) in line:
             in_download = True
         if in_download:
@@ -60,26 +61,17 @@ class GoLang(umake.frameworks.baseinstaller.BaseInstaller):
                 url = p.group(1)
             p = re.search(r'<td><tt>(\w+)</tt></td>', line)
             with suppress(AttributeError):
-                sha1 = p.group(1)
+                sha = p.group(1)
             if "</tr>" in line:
                 in_download = False
 
-        if url is None and sha1 is None:
+        if url is None and sha is None:
             return (None, in_download)
-        return ((url, sha1), in_download)
+        return ((url, sha), in_download)
 
     def post_install(self):
         """Add go necessary env variables"""
         add_env_to_user(self.name, {"PATH": {"value": os.path.join(self.install_path, "bin")},
-                                    "GOROOT": {"value": self.install_path}})
-        UI.delayed_display(DisplayMessage(_("You need to restart a shell session for your installation to work")))
-
-    @property
-    def is_installed(self):
-        """Checks path and requirements for installation"""
-        if not super().is_installed:
-            return False
-        if not os.path.isfile(os.path.join(self.install_path, "bin", "go")):
-            logger.debug("{} binary isn't installed".format(self.name))
-            return False
-        return True
+                                    "GOROOT": {"value": self.install_path, "keep": False}})
+        UI.delayed_display(DisplayMessage(_("You need to restart your current shell session for your {} installation "
+                                            "to work properly").format(self.name)))
